[![MIT](https://img.shields.io/github/license/finsberg/pulse2)](https://github.com/finsberg/pulse2/blob/main/LICENSE)
[![PyPI version](https://badge.fury.io/py/pulse2.svg)](https://pypi.org/project/fenicsx_pulse/)
[![Tests](https://github.com/finsberg/pulse2/actions/workflows/test.yml/badge.svg)](https://github.com/finsberg/pulse2/actions/workflows/test.yml)
[![Pre-commit](https://github.com/finsberg/pulse2/actions/workflows/pre-commit.yml/badge.svg)](https://github.com/finsberg/pulse2/actions/workflows/pre-commit.yml)
[![Deploy static content to Pages](https://github.com/finsberg/pulse2/actions/workflows/build_docs.yml/badge.svg)](https://github.com/finsberg/pulse2/actions/workflows/build_docs.yml)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Create and publish a Docker image](https://github.com/finsberg/pulse2/actions/workflows/docker-image.yml/badge.svg)](https://github.com/finsberg/pulse2/pkgs/container/fenicsx_pulse)
[![Coverage](https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/finsberg/a7290de789564f03eb6b1ee122fce423/raw/pulse2-coverage.json)](https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/finsberg/a7290de789564f03eb6b1ee122fce423/raw/pulse2-coverage.json)

# Pulse2

`pulse2` is a FEniCS-based cardiac mechanics solver. It is in part inspired by [`fenics-pulse`](https://github.com/finsberg/pulse) and [`pulse`](https://bitbucket.org/peppu/pulse) but it created to make the transition to [`fenicsx-pulse`](https://github.com/finsberg/fenicsx-pulse) easier.

# Quickstart

TBW


## Contributing
See https://finsberg.github.io/fenicsx-pulse/CONTRIBUTING.html
